@@ -874,14 +874,14 @@ class Application(Gtk.Application):
         self.notes_hidden = True
         self.update_dummy_window()
 
-    def new_note(self, button, parent=None):
+    def new_note(self, button=None, parent=None):
         if parent is None:
             x = 40
             y = 40
         else:
             x = parent.x + 20
             y = parent.y + 20
-        while(True):
+        while True:
             found = False
             for note_info in self.file_handler.get_note_list(self.note_group):
                 if note_info['x'] == x and note_info['y'] == y:
